==> gorilla-notebook-0.4.1.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.output.text.js <==
goog.provide('pinkgorilla.output.text');
goog.require('cljs.core');
goog.require('clojure.string');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.output.html');
pinkgorilla.output.text.line_with_br = (function pinkgorilla$output$text$line_with_br(t){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"span.font-mono.text-lg.whitespace-pre","span.font-mono.text-lg.whitespace-pre",-559173342),t], null),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"br","br",934104792)], null)], null);
});
pinkgorilla.output.text.text = (function pinkgorilla$output$text$text(t){
var lines = clojure.string.split.cljs$core$IFn$_invoke$arity$2(t,/\n/);
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"gorilla_ui","gorilla_ui",-568848226),"text"], null)], null),cljs.core.map.cljs$core$IFn$_invoke$arity$2(pinkgorilla.output.text.line_with_br,lines));
});
pinkgorilla.output.text.output_text = (function pinkgorilla$output$text$output_text(output,seg_id){
var temp__5733__auto__ = new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output);
if(cljs.core.truth_(temp__5733__auto__)){
var content = temp__5733__auto__;
var h = pinkgorilla.output.text.text(new cljs.core.Keyword(null,"text","text",-1790561697).cljs$core$IFn$_invoke$arity$1(content));
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.output.text","/tmp/form-init7190841119320184072.clj",20,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, ["rendering text: ",content,"h: ",h], null);
}),null)),null,-80667806);

return pinkgorilla.output.html.output_html(new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"content","content",15833224),h], null),seg_id);
} else {
return null;
}
});

//# sourceMappingURL=pinkgorilla.output.text.js.map

==> gorilla-notebook-0.4.2.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.output.text.js <==
goog.provide('pinkgorilla.output.text');
goog.require('cljs.core');
goog.require('clojure.string');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.output.html');
pinkgorilla.output.text.line_with_br = (function pinkgorilla$output$text$line_with_br(t){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"span.font-mono.text-lg.whitespace-pre","span.font-mono.text-lg.whitespace-pre",-559173342),t], null),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"br","br",934104792)], null)], null);
});
pinkgorilla.output.text.text = (function pinkgorilla$output$text$text(t){
var lines = clojure.string.split.cljs$core$IFn$_invoke$arity$2(t,/\n/);
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"gorilla_ui","gorilla_ui",-568848226),"text"], null)], null),cljs.core.map.cljs$core$IFn$_invoke$arity$2(pinkgorilla.output.text.line_with_br,lines));
});
pinkgorilla.output.text.output_text = (function pinkgorilla$output$text$output_text(output,seg_id){
var temp__5733__auto__ = new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output);
if(cljs.core.truth_(temp__5733__auto__)){
var content = temp__5733__auto__;
var h = pinkgorilla.output.text.text(new cljs.core.Keyword(null,"text","text",-1790561697).cljs$core$IFn$_invoke$arity$1(content));
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.output.text","/tmp/form-init4304146612373765484.clj",20,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, ["rendering text: ",content,"h: ",h], null);
}),null)),null,1318731196);

return pinkgorilla.output.html.output_html(new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"content","content",15833224),h], null),seg_id);
} else {
return null;
}
});

//# sourceMappingURL=pinkgorilla.output.text.js.map
